@@ -42,7 +42,10 @@ def model_dict_to_str(
     d: dict,
     edgedb_conversion_map: T.Dict[str, T.Dict[str, str]],
     set_links_d: T.Dict[str, "Resolver"] = None,
+    force_replace: bool = False,  # make this true for inserts
 ) -> T.Tuple[str, T.Dict[str, T.Any]]:
+    from .resolver import UpdateOperation
+
     field_strs: T.List[str] = []
     variables = {}
     for field_name, val in d.items():
@@ -65,6 +68,8 @@ def model_dict_to_str(
     if set_links_d:
         for field_name, resolver in set_links_d.items():
             update_operation_str = resolver.update_operation_str
+            if force_replace:
+                update_operation_str = UpdateOperation.REPLACE.value
             if not update_operation_str:
                 raise NodeException(
                     f"Update resolver for {field_name} does not have an update operation."
@@ -85,16 +90,12 @@ def model_dict_to_str(
     return s, variables
 
 
-def basemodel_to_str(
-    model: BaseModelType,
-    default_replace: bool = False,
-    fields_to_exclude: T.Set[str] = None,
-) -> T.Tuple[str, T.Dict[str, T.Any]]:
-    # should exclude_none = True?
+def make_set_links_d(
+    model: BaseModel, model_d: dict, default_replace: bool = False
+) -> T.Dict[str, "ResolverType"]:
+    """mutates model_d and returns set links d"""
     from .resolver import Resolver, UpdateOperation
 
-    model_d = model.dict(exclude_none=True, exclude=fields_to_exclude)
-
     set_links_d = {}
     for field_name in model.__fields__.keys():
         val = getattr(model, field_name)
@@ -104,11 +105,27 @@ def basemodel_to_str(
             set_links_d[field_name] = val
             if field_name in model_d:
                 del model_d[field_name]
+    return set_links_d
+
+
+def basemodel_to_str(
+    model: BaseModelType,
+    default_replace: bool = False,
+    fields_to_exclude: T.Set[str] = None,
+    force_replace: bool = False,
+) -> T.Tuple[str, T.Dict[str, T.Any]]:
+    # should exclude_none = True?
+    model_d = model.dict(exclude_none=True, exclude=fields_to_exclude)
+
+    set_links_d = make_set_links_d(
+        model=model, model_d=model_d, default_replace=default_replace
+    )
 
     return model_dict_to_str(
         d=model_d,
         edgedb_conversion_map=model._edgedb_conversion_map,
         set_links_d=set_links_d,
+        force_replace=force_replace,
     )
 
 
@@ -329,7 +346,9 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
         )
         # I think default_replace=True is correct here. Your intention is to make sure these links are SET, not updated
         # if your intention is for them to update on upsert, then add ADD to the resolver
-        s, variables = basemodel_to_str(insert, default_replace=True)
+        s, variables = basemodel_to_str(
+            insert, default_replace=True, force_replace=True
+        )
         insert_str = f"INSERT {cls._model_name} {s}"
         conflict_str = ""
         if custom_on_conflict_str:
@@ -633,12 +652,12 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         cls: T.Type[ThisNodeType],
         patch: PatchType,
         resolver_with_filter: "ResolverType",
-        set_links_d: T.Dict[str, "Resolver"] = None,
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
     ) -> T.Optional[ThisNodeType]:
         update_d = cls.build_update_d_from_patch(patch=patch)
-        if not update_d:
+        set_links_d = make_set_links_d(model=patch, model_d=update_d)
+        if not update_d and not set_links_d:
             raise NodeException("No update registered.")
         node = await cls._update(
             resolver=resolver_with_filter,
