@@ -226,6 +226,38 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         self._filter = filter_str
         return self
 
+    def filter_by(self, **kwargs):
+        """For now, only expecting one key value pair to be given, but could be more in future"""
+        kwargs = {k: v for k, v in kwargs.items() if v is not None}
+        if not kwargs:
+            raise ResolverException("Nothing to filter by.")
+        conversion_map = self._node._edgedb_conversion_map
+        filter_strs = []
+        variables = {}
+        for field_name, field_value in kwargs.items():
+            cast = conversion_map[field_name]["cast"]
+            filter_strs.append(f".{field_name} = <{cast}>${field_name}")
+            variables[field_name] = field_value
+        filter_str = " AND ".join(filter_strs)
+        return self.filter(filter_str=filter_str, variables=variables)
+
+    def filter_in(self, **kwargs: list):
+        kwargs = {k: v for k, v in kwargs.items() if v is not None}
+        if not kwargs:
+            raise ResolverException("Nothing to filter by.")
+        conversion_map = self._node._edgedb_conversion_map
+        filter_strs = []
+        variables = {}
+        for field_name, value_lst in kwargs.items():
+            cast = conversion_map[field_name]["cast"]
+            variable_name = f"{field_name}s"
+            filter_strs.append(
+                f".{field_name} in array_unpack(<array<{cast}>>${variable_name})"
+            )
+            variables[variable_name] = value_lst
+        filter_str = " AND ".join(filter_strs)
+        return self.filter(filter_str=filter_str, variables=variables)
+
     def extra_fields(
         self: ThisResolverType,
         extra_fields_str: str,
@@ -401,18 +433,9 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         if key not in self._node._exclusive_fields:
             raise ResolverException(f"Field '{key}' is not exclusive.")
         # this is to avoid nested collisions
+        conversion_map = self._node._edgedb_conversion_map
         variables = {key: value}
-        if isinstance(value, UUID) or key == "id":
-            value_str = f"<uuid>${key}"
-        elif isinstance(value, str) or isinstance(value, Enum):
-            # assume it is a string, can add if int or datetime i guess...
-            value_str = f"<str>${key}"
-        elif isinstance(value, int):
-            value_str = f"<int16>${key}"
-        else:
-            value_str = value
-            # need to test more: is this correct? Prob cause now using raw string given, no variables
-            variables = {}
+        value_str = f'<{conversion_map[key]["cast"]}>${key}'
         self.filter(f".{key} = {value_str}", variables=variables)
         query_str = self.full_query_str()
         with safe_span(op=f"get.{self._model_name}", description=query_str[:200]):
